@@ -1,8 +1,8 @@
 import wave
-import os,sys
-import  numpy as np
-sys.path.append('./')
-sys.path.append('../')
+import sys,os
+from os import  path
+sys.path.append(path.dirname(__file__))
+sys.path.append(os.path.dirname(path.dirname(__file__)))
 from moviepy.editor import AudioFileClip
 from commFunction import get_rms,get_ave_rms,get_one_channel_data,get_file_duration,get_data_array
 from formatConvert import pcm2wav
