@@ -4,11 +4,10 @@ import sys,os
 from os import  path
 sys.path.append(os.path.dirname(path.dirname(__file__)))
 sys.path.append(path.dirname(__file__))
-from commFunction import getip,log_time,global_result,sftp_connect,sftp_put,sftp_disconnect,get_file_path,get_data_array,get_rms,make_out_file
+from commFunction import getip,log_time,global_result,sftp_connect,sftp_put,sftp_disconnect,get_rms
 import shutil
 from  socketClient import SocketClient
-import datetime
-
+import numpy as np
 
 
 def polqa_client_test(src,test,samplerate,mode=0):
@@ -17,6 +16,18 @@ def polqa_client_test(src,test,samplerate,mode=0):
     curpath = str(curip) + '_'+str(curtime)
     os.mkdir(curpath)
 
+    if mode == 1:
+        f = open(test, "rb")
+        curaudiodata = np.fromfile(f, dtype=np.int16)
+        curaudiodata = curaudiodata.astype(np.float64)
+        currms = get_rms(curaudiodata)
+        adjustlevel = -26 - currms
+
+        factor = 10 ** (adjustlevel / 20)
+        urframe = curaudiodata * factor
+        urframe = urframe.astype(np.int16)
+        urframe.tofile(test)
+        f.close()
     curdata = global_result.get_data()
     curdata['module'] = 'clientA'
     curdata['method'] = 'requestA'
@@ -28,17 +39,7 @@ def polqa_client_test(src,test,samplerate,mode=0):
     #ssh
     shutil.copy(src,curpath)
     shutil.copy(test, curpath)
-    if mode == 1:
-        curFileName = curpath + '//' + curdata['testFile']
-        curaudiodata,curfs,curch = get_data_array(curFileName)
 
-
-        currms = get_rms(curaudiodata)
-        adjustlevel = -26 - currms
-
-        factor = 10 ** (adjustlevel / 20)
-        urframe = curaudiodata * factor
-        make_out_file(curFileName,urframe,curfs,curch)
     dstpath = '/home/netease/polqa'
 
 
@@ -63,7 +64,7 @@ if __name__ == '__main__':
     import platform
     print(platform.uname())
     print(sys.platform)
-    polqa_client_test(src='src.wav',test='2.wav',samplerate=48000,mode=1)
+    polqa_client_test(src='src.pcm',test='test.pcm',samplerate=48000,mode=0)
 
     exit(0)
     # client, sftp = sftp_connect(username, password, serverIP, port=port)
