@@ -1,10 +1,11 @@
 # -*- coding:utf-8 -*-
-import sys
-import  os,time
-from os import path
+
+import  time
+
 import copy
-sys.path.append('./')
-sys.path.append('../')
+import sys,os
+from os import  path
+sys.path.append(os.path.dirname(path.dirname(__file__)))
 from commFunction import global_result,sftp_connect,sftp_get,sftp_disconnect,constMosResult
 import shutil
 from  socketClient import SocketClient
