@@ -8,7 +8,7 @@ from .STI.cal_sti import cal_sti
 from .STOI.STOI import *
 from .resample.resampler import resample,restruct
 from .timeAligment.time_align import cal_fine_delay
-from .commFunction import get_data_array,get_file_path,get_rms,convert_error_header
+from .commFunction import get_data_array,get_file_path,get_rms,convert_error_header,make_out_file
 from .PCC.Pearson_CC import cal_PCC,get_max_cc_by_dll
 from .Noise_Suppression.noiseFuction import cal_noise_Supp
 from .SNR_ESTIMATION.MATCH_SIG import match_sig
@@ -33,7 +33,7 @@ from ctypes import  *
 
 def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFile=None,aecCaliFile=None,outFile=None,noiseFile=None,samplerate=16000,
                           bitwidth=2,channel=1,refOffset=0,testOffset=0,maxComNLevel =-48.0,speechPauseLevel=-35.0,audioType=0,
-                          aecStartPoint=0,aecTargetType=0,aecScenario=0,rmsCalsection=None):
+                          aecStartPoint=0,aecTargetType=0,aecScenario=0,rmsCalsection=None,polqaMode=0):
     """
     :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS/MUSIC/MATCH/
                     TRANSIENT/GAINTABLE/ATTACKRELEASE/MUSICSTA/AGCDELAY/MATCHAEC/
@@ -85,6 +85,7 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
     :param aecTargetType  0:Chiness 1:English 2:Single Digit 3:Music  计算MATCHAEC/ELRE
     :param aecScenario 计算aec mos专用     0:'doubletalk_with_movement', 1:'doubletalk', 2:'farend_singletalk_with_movement', 3:'farend_singletalk', 4:'nearend_singletalk'
     :param rmsCalsection 计算rms的区间 TRMS和ARMS需要，时间单位s，比如：[1,20]
+    :param polqaMode 计算polqa的模式 0:默认模式  1: 理想模式：排除小声音的影响，把声音校准到理想点平 -26db
     :return:
     """
     paraDicts = {
@@ -107,7 +108,8 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,micFile=None,cleFil
         "aecStartPoint":aecStartPoint,
         "aecTargetType":aecTargetType,
         'aecScenario':aecScenario,
-        'rmsCalsection':rmsCalsection
+        'rmsCalsection':rmsCalsection,
+        'polqaMode':polqaMode
     }
     comAuQUA = computeAudioQuality(**paraDicts)
     return methodcaller(metrics)(comAuQUA)
