@@ -385,6 +385,8 @@ def get_rms(records):
     '''
     #return math.sqrt(sum([x * x for x in records])/len(records))
     data = records.astype(np.float32).tolist()
+    if len(data) == 0:
+        return -99.9
     rms = math.sqrt(sum([(x/32767) * (x/32767) for x in data])/len(data))
     dBrmsValue = 20*math.log10(rms + 1.0E-6)
     return dBrmsValue
