@@ -77,6 +77,7 @@ class computeAudioQuality():
         self.aecScenario = kwargs['aecScenario']
         self.aecTargetType = kwargs["aecTargetType"]
         self.rmsCalsection = kwargs["rmsCalsection"]
+        self.polqaMode = kwargs["polqaMode"]
         #maxComNLevel=c_double(-48.0),speechPauseLevel=c_double(-35.0)
 
     def __chcek_valid(self):
@@ -171,8 +172,7 @@ class computeAudioQuality():
 
         self.__double_end_check()
         curCH,curBwidth,curSR = self.__check_format(self.testFile)
-
-        result =  polqa_client_test(wav2pcm(self.refFile),wav2pcm(self.testFile),curSR)
+        result =  polqa_client_test(wav2pcm(self.refFile),wav2pcm(self.testFile),curSR,mode=self.polqaMode)
         time.sleep(2)
         return  result
 
